@@ -9,7 +9,7 @@
 use strict; use warnings;
 package Dist::Zilla::Plugin::DualBuilders;
 BEGIN {
-  $Dist::Zilla::Plugin::DualBuilders::VERSION = '1.000';
+  $Dist::Zilla::Plugin::DualBuilders::VERSION = '1.001';
 }
 BEGIN {
   $Dist::Zilla::Plugin::DualBuilders::AUTHORITY = 'cpan:APOCAL';
@@ -21,6 +21,7 @@ use Moose 1.03;
 
 with 'Dist::Zilla::Role::PrereqSource' => { -version => '3.101461' };
 with 'Dist::Zilla::Role::InstallTool' => { -version => '3.101461' };
+with 'Dist::Zilla::Role::AfterBuild' => { -version => '3.101461' };
 
 
 {
@@ -35,6 +36,13 @@ with 'Dist::Zilla::Role::InstallTool' => { -version => '3.101461' };
 	no Moose::Util::TypeConstraints;
 }
 
+
+has block_test => (
+	is => 'ro',
+	isa => 'Bool',
+	default => 1,
+);
+
 has _buildver => (
 	is => 'rw',
 	isa => 'Str',
@@ -111,6 +119,37 @@ sub register_prereqs {
 	}
 }
 
+sub after_build {
+        my( $self, $root ) = @_;
+
+        return if ! $self->block_test;
+
+	# The builders have done their job, now we block them from running the testsuite twice!
+	my $testers = $self->zilla->plugins_with(-TestRunner);
+		foreach my $t ( @$testers ) {
+		if ( $t =~ /MakeMaker/ and $self->prefer eq 'build' ) {
+			$self->log_debug( 'Blocking ExtUtils::MakeMaker from running the testsuite' );
+			$self->_remove_tester( $t );
+		} elsif ( $t =~ /ModuleBuild/ and $self->prefer eq 'make' ) {
+			$self->log_debug( 'Blocking Module::Build from running the testsuite' );
+			$self->_remove_tester( $t );
+		}
+	}
+}
+
+sub _remove_tester {
+	my( $self, $tester ) = @_;
+
+	# TODO RJBS will kill me! What's a better way to do this?
+	my $plugins = $self->zilla->plugins;
+	foreach my $i ( 0 .. $#{ $plugins } ) {
+		if ( $plugins->[$i] == $tester ) {
+			splice( @$plugins, $i, 1 );
+			last;
+		}
+	}
+}
+
 no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
@@ -119,7 +158,7 @@ __PACKAGE__->meta->make_immutable;
 __END__
 =pod
 
-=for Pod::Coverage register_prereqs setup_installer
+=for Pod::Coverage register_prereqs setup_installer after_build
 
 =for stopwords MakeMaker ModuleBuild dist dzil prereq prereqs
 
@@ -129,13 +168,13 @@ Dist::Zilla::Plugin::DualBuilders - Allows use of Module::Build and ExtUtils::Ma
 
 =head1 VERSION
 
-  This document describes v1.000 of Dist::Zilla::Plugin::DualBuilders - released December 13, 2010 as part of Dist-Zilla-Plugin-DualBuilders.
+  This document describes v1.001 of Dist::Zilla::Plugin::DualBuilders - released December 15, 2010 as part of Dist-Zilla-Plugin-DualBuilders.
 
 =head1 DESCRIPTION
 
 This plugin allows you to specify ModuleBuild and MakeMaker in your L<Dist::Zilla> F<dist.ini> and select
 only one as your prereq. Normally, if this plugin is not loaded you will end up with both in your prereq list
-and this is obviously not what you want!
+and this is obviously not what you want! Also, this will block both builders from running the testsuite twice.
 
 	# In your dist.ini:
 	[ModuleBuild]
@@ -150,6 +189,13 @@ Sets your preferred builder. This builder will be the one added to the prereqs.
 
 The default is: build
 
+=head2 block_test
+
+This is a boolean value determining if we will block both testers from running the testsuite. If you have both
+builders loaded, you will run the testsuite twice! If you want this behavior, please set this value to false.
+
+The default is: true
+
 =head1 SEE ALSO
 
 Please see those modules/websites for more information related to this module.
